4.50. umbra.ui.widgets.active_QLabelsCollection — Umbra 1.0.9 documentation

# 4.50. umbra.ui.widgets.active_QLabelsCollection

active_QLabel.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `Active_QLabelsCollection` class.

Others:

## 4.50.1. Module Attributes

`umbra.ui.widgets.active_QLabelsCollection.` `LOGGER`

## 4.50.2. Classes

class `umbra.ui.widgets.active_QLabelsCollection.` `Active_QLabelsCollection`(parent=None)

  Bases: `PyQt4.QtCore.QObject`

  Defines a QObject subclass providing a group for `umbra.ui.widgets.active_QLabel.Active_QLabel` class objects.

  Initializes the class.

  Parameters: | parent (QObject) – Widget parent.

  `activeLabelClicked`

    This signal is emited by the `Active_QLabelsCollection` class when one of its `umbra.ui.widgets.active_QLabel.Active_QLabel` child has been clicked. ( pyqtSignal )

    Returns: | Current clicked active label.
    Return type: | Active_QLabel

  `activeLabelPressed`

    This signal is emited by the `Active_QLabelsCollection` class when one of its `umbra.ui.widgets.active_QLabel.Active_QLabel` child has been pressed. ( pyqtSignal )

    Returns: | Current clicked active label.
    Return type: | Active_QLabel

  `activeLabelReleased`

    This signal is emited by the `Active_QLabelsCollection` class when one of its `umbra.ui.widgets.active_QLabel.Active_QLabel` child has been released. ( pyqtSignal )

    Returns: | Current clicked active label.
    Return type: | Active_QLabel

  `activeLabelToggled`

    This signal is emited by the `Active_QLabelsCollection` class when one of its `umbra.ui.widgets.active_QLabel.Active_QLabel` child has been toggled. ( pyqtSignal )

    Returns: | Current checked active label.
    Return type: | Active_QLabel

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject

  `activeLabels`

    Property for self.__activeLabels attribute.

    Returns: | self.__activeLabels.
    Return type: | list

  `addActiveLabel`(activeLabel)

    Adds given Active_QLabel Widget.

    Parameters: | activeLabel (Active_QLabel) – Active label to add.
    Returns: | Method success.
    Return type: | bool

  `removeActiveLabel`(activeLabel)

    Removes given Active_QLabel Widget.

    Parameters: | activeLabel (Active_QLabel) – Active label to remove.
    Returns: | Method success.
    Return type: | bool

  `getToggledActiveLabel`()

    Returns the toggled Active_QLabel Widget.

    Returns: | Checked active label.
    Return type: | bool

  `getActiveLabelIndex`(activeLabel)

    Returns given Active_QLabel Widget index.

    Parameters: | activeLabel (Active_QLabel) – Active label to retrieve index.
    Returns: | Active label index.
    Return type: | int

  `getActiveLabelFromIndex`(index)

    Returns the Active_QLabel Widget from given index.

    Parameters: | index (int) – Index.
    Returns: | Active label.
    Return type: | Active_QLabel